Enum AppleCodeSignBehavior

pub enum AppleCodeSignBehavior {
    DoNothing,
    Ignore,
    Fail,
}
Controls the behavior of the super::link_package function when it encounters a binary that needs to be signed on macOS (both Intel and Apple Silicon).

Variants



DoNothing

Do nothing (do not attempt to sign any binary)



Ignore

Ignore if the signing fails



Fail

Bubble up the error if the code signing fails (default)